The file `pendulum_3d_cartesian_full_time.mat` has been generated using `metis` by PLK.
The content of file `pendulum_3d_cartesian_full_time.mat`
is parsed in script `s005_run_pendulum_3d_cartesian_full_time.py`
and exported to file `pendulum_3d_cartesian_full_time.csv`.

On the contrary, the file `test/reference_results/pendulum_3d_cartesian_full_time.csv` is calculated with `pydykit`.
